# Customized Derived Image for Maker Edition

This example shows how to leverage a derived image and entrypoint shim to perform some custom logic prior to startup of the Gateway.  Specifically, we'll make sure that any non-Maker supported modules have been removed from the image prior to startup.

## Prerequisites

A Docker Compose solution is provided here and is used for the basis of building and starting the Ignition container.  Familiarity with Docker Compose is assumed.

## Building the solution

We're using both the `build:` and `image:` directives in the Compose YAML in order to direct compose to build and tag a Docker image accordingly.  When you have only the `image:` directive, Docker will attempt to pull (if there isn't a local tag already present) the specified image.

    $ docker compose build

If you investigate the `gw-build` folder in this solution, you'll find two components used for the derived image build:

- `docker-entrypoint-shim.sh` - This script performs removal of non-Maker modules when applicable and then kicks off the main Ignition gateway entrypoint script from the upstream official image.
- `Dockerfile` - This guides the Docker image build to inherit from the upstream official image and copy in our entrypoint shim script.

## Running the solution

Once you've built the local image and tagged it according to the `image:` directive in the Compose YAML, we can now specify the secrets by opening and editing the following files:

- `secrets/GATEWAY_ACTIVATION_TOKEN` - Place your Maker activation token in this file.
- `secrets/GATEWAY_ADMIN_PASSWORD` - Set your initial gateway admin password here.

You can also choose to remove these `secrets:` definitions from your `gateway` service in the Compose YAML and just use the interactive commissioning process via the gateway webpage.  

At this point, you're now ready to launch the gateway container with:

    $ docker compose up -d

## Shutting down the solution

If you're ready to shutdown the gateway container, you can:

    $ docker compose down

Note that the volume will still remain even with the above command removing the container.  You can add a `-v` flag to the `down` command to also remove the data volume.
